@@ -9,7 +9,7 @@
 #
 package Test::Moose::More;
 {
-  $Test::Moose::More::VERSION = '0.013'; # TRIAL
+  $Test::Moose::More::VERSION = '0.014'; # TRIAL
 }
 
 # ABSTRACT: More tools for testing Moose packages
@@ -223,8 +223,10 @@ sub validate_thing {
                 skip 'Cannot examine attribute metaclass in roles', 1
                     if (find_meta($thing)->isa('Moose::Meta::Role'));
 
-                    local $THING_NAME = "${thing}'s attribute $name";
+                local $THING_NAME = "${thing}'s attribute $name";
+                $tb->subtest("[subtest] checking $THING_NAME" => sub {
                     _validate_attribute(find_meta($thing)->get_attribute($name), %$opts);
+                });
             }
         }
     }
@@ -277,7 +279,7 @@ sub _validate_attribute {
         map  { $_ => delete $opts{"-$_"} }
         map  { s/^-//; $_                }
         grep { /^-/                      }
-        keys %opts
+        sort keys %opts
         ;
 
     validate_thing $att => %thing_opts
@@ -307,6 +309,8 @@ sub _attribute_options_ok {
     local $Test::Builder::Level = $Test::Builder::Level + 1;
     my $name = $att->name;
 
+    my $thing_name = _thing_name($name, $att);
+
     # XXX do we really want to do this?
     if (my $is = delete $opts{is}) {
         $opts{accessor} = $name if $is eq 'rw' && ! exists $opts{accessor};
@@ -319,13 +323,13 @@ sub _attribute_options_ok {
         my $has      = "has_$property";
 
         defined $value
-            ? ok($att->$has,  "attribute $name has a $property")
-            : ok(!$att->$has, "attribute $name does not have a $property")
+            ? ok($att->$has,  "$thing_name has a $property")
+            : ok(!$att->$has, "$thing_name does not have a $property")
             ;
-        is($att->$property, $value, "$name: $property correct")
+        is($att->$property, $value, "$thing_name option $property correct")
     };
 
-    $check->($_) for grep { any(@check_opts) eq $_ } keys %opts;
+    $check->($_) for grep { any(@check_opts) eq $_ } sort keys %opts;
 
     do { $tb->skip("cannot test '$_' options yet", 1); delete $opts{$_} }
         for grep { exists $opts{$_} } @unhandled_opts;
@@ -334,7 +338,7 @@ sub _attribute_options_ok {
 
         $opts{init_arg}
             ?  $check->('init_arg')
-            : ok(!$att->has_init_arg, "$name has no init_arg")
+            : ok(!$att->has_init_arg, "$thing_name has no init_arg")
             ;
         delete $opts{init_arg};
     }
@@ -342,8 +346,8 @@ sub _attribute_options_ok {
     if (exists $opts{lazy}) {
 
         delete $opts{lazy}
-            ? ok($att->is_lazy,  "attribute $name is lazy")
-            : ok(!$att->is_lazy, "attribute $name is not lazy")
+            ? ok($att->is_lazy,  "$thing_name is lazy")
+            : ok(!$att->is_lazy, "$thing_name is not lazy")
             ;
     }
 
@@ -371,7 +375,7 @@ Test::Moose::More - More tools for testing Moose packages
 
 =head1 VERSION
 
-This document describes version 0.013 of Test::Moose::More - released September 30, 2012 as part of Test-Moose-More.
+This document describes version 0.014 of Test::Moose::More - released October 04, 2012 as part of Test-Moose-More.
 
 =head1 SYNOPSIS
 
@@ -491,13 +495,15 @@ additional class-specific tests.
 
 Run checks against an attribute.
 
-Not yet documented or tested exhaustively.
+Not yet documented or tested exhaustively; please see t/validate_attribute.t
+for usage details until released in a non TRIAL form.
 
 =head2 attribute_options_ok
 
 Validates that an attribute is set up as expected.
 
-Not yet documented or tested exhaustively.
+Not yet documented or tested exhaustively; please see t/validate_attribute.t
+for usage details until released in a non TRIAL form.
 
 =head1 SEE ALSO
 
